@@ -338,7 +338,7 @@ class WayfirePanel::impl
                                 // check if the x position of the mouse is within the plugin
                                 Gtk::Allocation alloc = plugin->get_allocation ();
 
-                                if (event->x_root >= alloc.get_x () && event->x_root <= alloc.get_x () + alloc.get_width())
+                                if (event->x_root >= alloc.get_x () && event->x_root <= alloc.get_x () + alloc.get_width ())
                                 {
                                     conf_plugin = plugin->get_name();
                                     if (conf_plugin == "spacing") cplug.hide ();
@@ -361,17 +361,23 @@ class WayfirePanel::impl
 
     void do_configure()
     {
+        this->get_window ().set_sensitive (false);
         open_config_dialog ();
+        this->get_window ().set_sensitive (true);
     }
 
     void do_plugin_configure()
     {
+        this->get_window ().set_sensitive (false);
         plugin_config_dialog (conf_plugin.c_str());
+        this->get_window ().set_sensitive (true);
     }
 
     void do_notify_configure()
     {
+        this->get_window ().set_sensitive (false);
         plugin_config_dialog ("notify");
+        this->get_window ().set_sensitive (true);
     }
 
     void do_appearance_set()
@@ -582,6 +588,8 @@ class WayfirePanel::impl
             return;
         }
 
+        if (!this->get_window().is_sensitive()) return;
+
         for (auto& w : left_widgets)
             if (name == w->widget_name) w->command (cmd);
         for (auto& w : right_widgets)
